@@ -1,5 +1,5 @@
 {-# LANGUAGE Trustworthy #-}
-{-# LANGUAGE CPP, OverloadedStrings #-}
+{-# LANGUAGE OverloadedStrings #-}
 
 -- |
 -- Module      : Criterion.IO
@@ -28,11 +28,7 @@ module Criterion.IO
 
 import qualified Data.Aeson as Aeson
 import Data.Binary (Binary(..), encode)
-#if MIN_VERSION_binary(0, 6, 3)
 import Data.Binary.Get (runGetOrFail)
-#else
-import Data.Binary.Get (runGetState)
-#endif
 import Data.Binary.Put (putByteString, putWord16be, runPut)
 import qualified Data.ByteString.Char8 as B
 import Criterion.Types (Report(..))
@@ -52,7 +48,7 @@ header = runPut $ do
 
 -- | The magic string we expect to start off the header.
 headerRoot :: String
-headerRoot = "criterio"
+headerRoot = "criterion"
 
 -- | The current version of criterion, encoded into a string that is
 -- used in files.
@@ -81,7 +77,6 @@ readRecords path = withFile path ReadMode hGetRecords
 writeRecords :: Binary a => FilePath -> [a] -> IO ()
 writeRecords path rs = withFile path WriteMode (flip hPutRecords rs)
 
-#if MIN_VERSION_binary(0, 6, 3)
 readAll :: Binary a => Handle -> IO [a]
 readAll handle = do
   let go bs
@@ -90,16 +85,6 @@ readAll handle = do
                          Left (_, _, err) -> fail err
                          Right (bs', _, a) -> (a:) `fmap` go bs'
   go =<< L.hGetContents handle
-#else
-readAll :: Binary a => Handle -> IO [a]
-readAll handle = do
-  let go i bs
-         | L.null bs = return []
-         | otherwise =
-            let (a, bs', i') = runGetState get bs i
-             in (a:) `fmap` go i' bs'
-  go 0 =<< L.hGetContents handle
-#endif
 
 -- | On disk we store (name,version,reports), where
 --   'version' is the version of Criterion used to generate the file.
@@ -118,12 +103,12 @@ readJSONReports path =
        Right (tg,vers,_)
          | tg == headerRoot && vers == critVersion -> return res
          | otherwise ->
-            do hPutStrLn stderr $ "Warning, readJSONReports: mismatched header, expected " 
+            do hPutStrLn stderr $ "Warning, readJSONReports: mismatched header, expected "
                                   ++ show (headerRoot,critVersion) ++ " received " ++ show (tg,vers)
-               return res         
+               return res
 
 -- | Write a list of reports to a JSON file.  Includes a header, which
--- includes the current Criterion version number.  This should be 
+-- includes the current Criterion version number.  This should be
 -- the inverse of `readJSONReports`.
 writeJSONReports :: FilePath -> [Report] -> IO ()
 writeJSONReports fn rs =
