@@ -25,22 +25,23 @@ module Criterion.Main.Options
 
 import Control.Monad (when)
 import Criterion.Analysis (validateAccessors)
-import Criterion.Main.Options.Internal (tabulate, text)
 import Criterion.Types (Config(..), Verbosity(..), measureAccessors,
                         measureKeys)
 import Data.Char (isSpace, toLower)
-import Data.Data (Data, Typeable)
+import Data.Data (Data)
 import Data.Int (Int64)
 import Data.List (isPrefixOf)
 import Data.Version (showVersion)
 import GHC.Generics (Generic)
 import Options.Applicative
-import Options.Applicative.Help (Chunk(..))
-import Options.Applicative.Help.Pretty ((.$.), Doc)
+import Options.Applicative.Help (Chunk(..), tabulate)
+import Options.Applicative.Help.Pretty ((.$.))
 import Options.Applicative.Types
 import Paths_criterion (version)
 import Prelude ()
 import Prelude.Compat
+import Prettyprinter (Doc, pretty)
+import Prettyprinter.Render.Terminal (AnsiStyle)
 import Statistics.Types (mkCL,cl95)
 import qualified Data.Map as M
 
@@ -59,7 +60,7 @@ data MatchType = Prefix
                  -- paths.
                | IPattern
                  -- ^ Same as 'Pattern', but case insensitive.
-               deriving (Eq, Ord, Bounded, Enum, Read, Show, Typeable, Data,
+               deriving (Eq, Ord, Bounded, Enum, Read, Show, Data,
                          Generic)
 
 -- | Execution mode for a benchmark program.
@@ -72,7 +73,7 @@ data Mode = List
             -- analysing performance numbers.
           | Run Config MatchType [String]
             -- ^ Run and analyse the given benchmarks.
-          deriving (Eq, Read, Show, Typeable, Data, Generic)
+          deriving (Eq, Read, Show, Data, Generic)
 
 -- | Default benchmarking configuration.
 defaultConfig :: Config
@@ -239,8 +240,10 @@ versionInfo :: String
 versionInfo = "built with criterion " <> showVersion version
 
 -- We sort not by name, but by likely frequency of use.
-regressionHelp :: Chunk Doc
+regressionHelp :: Chunk (Doc AnsiStyle)
 regressionHelp =
-    fmap (text "Regression metrics (for use with --regress):" .$.) $
-      tabulate [(text n,text d) | (n,(_,d)) <- map f measureKeys]
+    fmap (pretty "Regression metrics (for use with --regress):" .$.) $
+      tabulate
+        (prefTabulateFill defaultPrefs)
+        [(pretty n, pretty d) | (n,(_,d)) <- map f measureKeys]
   where f k = (k, measureAccessors M.! k)
